@@ -23,20 +23,12 @@
     .. moduleauthor::  Sebastian Wiesner  <lunaryorn@gmail.com>
 """
 
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
-
-try:
-    from subprocess import check_output
-except ImportError:
-    from pyudev._compat import check_output
-
-import os
-import sys
-import stat
+# isort: STDLIB
 import errno
-
-import six
+import os
+import stat
+import sys
+from subprocess import check_output
 
 
 def ensure_byte_string(value):
@@ -60,7 +52,7 @@ def ensure_unicode_string(value):
     decoded with the filesystem encoding (as in
     :func:`sys.getfilesystemencoding()`).
     """
-    if not isinstance(value, six.text_type):
+    if not isinstance(value, str):
         value = value.decode(sys.getfilesystemencoding())
     return value
 
@@ -82,7 +74,7 @@ def property_value_to_bytes(value):
         value = int(value)
     if isinstance(value, bytes):
         return value
-    return ensure_byte_string(six.text_type(value))
+    return ensure_byte_string(str(value))
 
 
 def string_to_bool(value):
@@ -93,9 +85,9 @@ def string_to_bool(value):
     ``False`` is returned.  Any other value raises a
     :exc:`~exceptions.ValueError`.
     """
-    if value not in ('1', '0'):
-        raise ValueError('Not a boolean value: {0!r}'.format(value))
-    return value == '1'
+    if value not in ("1", "0"):
+        raise ValueError("Not a boolean value: {0!r}".format(value))
+    return value == "1"
 
 
 def udev_list_iterate(libudev, entry):
@@ -129,11 +121,11 @@ def get_device_type(filename):
     """
     mode = os.stat(filename).st_mode
     if stat.S_ISCHR(mode):
-        return 'char'
+        return "char"
     elif stat.S_ISBLK(mode):
-        return 'block'
+        return "block"
     else:
-        raise ValueError('not a device file: {0!r}'.format(filename))
+        raise ValueError("not a device file: {0!r}".format(filename))
 
 
 def eintr_retry_call(func, *args, **kwargs):
@@ -152,6 +144,7 @@ def eintr_retry_call(func, *args, **kwargs):
     """
 
     # select.error inherits from Exception instead of OSError in Python 2
+    # isort: STDLIB
     import select
 
     while True:
@@ -195,5 +188,5 @@ def udev_version():
 
     .. versionadded:: 0.8
     """
-    output = ensure_unicode_string(check_output(['udevadm', '--version']))
+    output = ensure_unicode_string(check_output(["udevadm", "--version"]))
     return int(output.strip())
