@@ -20,36 +20,30 @@ Tests methods belonging to Device class.
 .. moduleauthor::  mulhern <amulhern@redhat.com>
 """
 
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
-import re
-import os
-import operator
+# isort: STDLIB
 import gc
+import operator
+import os
+import re
 from datetime import timedelta
 
-from hypothesis import given
-from hypothesis import settings
-from hypothesis import strategies
-
+# isort: THIRDPARTY
 import pytest
-import mock
-
-from pyudev import Device
-from pyudev import Devices
+from hypothesis import given, settings, strategies
 
+# isort: LOCAL
+from pyudev import Device, Devices
 from pyudev.device import Attributes, Tags
 
+from .._constants import _CONTEXT, _CONTEXT_STRATEGY, _DEVICE_DATA, _DEVICES, _UDEV_TEST
 from ..utils import is_unicode_string
 
-from .._constants import _CONTEXT
-from .._constants import _CONTEXT_STRATEGY
-from .._constants import _DEVICE_DATA
-from .._constants import _DEVICES
-from .._constants import _UDEV_TEST
+try:
+    # isort: STDLIB
+    from unittest import mock
+except ImportError:
+    # isort: THIRDPARTY
+    import mock
 
 
 class TestDevice(object):
@@ -60,12 +54,11 @@ class TestDevice(object):
     @given(strategies.sampled_from(_DEVICES))
     @settings(max_examples=5)
     def test_parent(self, a_device):
-        assert a_device.parent is None or \
-           isinstance(a_device.parent, Device)
+        assert a_device.parent is None or isinstance(a_device.parent, Device)
 
     _devices = [d for d in _DEVICES if d.parent is not None]
 
-    @pytest.mark.skipif(len(_devices) == 0, reason='no device with a parent')
+    @pytest.mark.skipif(len(_devices) == 0, reason="no device with a parent")
     @_UDEV_TEST(172, "test_child_of_parents")
     @given(strategies.sampled_from(_devices))
     @settings(max_examples=5)
@@ -74,7 +67,7 @@ class TestDevice(object):
 
     _devices = [d for d in _DEVICES if list(d.children)]
 
-    @pytest.mark.skipif(len(_devices) == 0, reason='no device with a child')
+    @pytest.mark.skipif(len(_devices) == 0, reason="no device with a child")
     @_UDEV_TEST(172, "test_children")
     @given(strategies.sampled_from(_devices))
     @settings(max_examples=5)
@@ -95,8 +88,8 @@ class TestDevice(object):
     _devices = [d for d in _DEVICES if d.find_parent(d.subsystem) is not None]
 
     @pytest.mark.skipif(
-        len(_devices) == 0,
-        reason='no device with a parent in the same subsystem')
+        len(_devices) == 0, reason="no device with a parent in the same subsystem"
+    )
     @given(strategies.sampled_from(_devices))
     @settings(max_examples=5)
     def test_find_parent(self, a_device):
@@ -107,41 +100,43 @@ class TestDevice(object):
     @given(strategies.sampled_from(_DEVICES))
     @settings(max_examples=5)
     def test_find_parent_no_devtype_mock(self, a_device):
-        funcname = 'udev_device_get_parent_with_subsystem_devtype'
+        funcname = "udev_device_get_parent_with_subsystem_devtype"
         spec = lambda d, s, t: None
         with mock.patch.object(
-                a_device._libudev, funcname, autospec=spec) as get_parent:
+            a_device._libudev, funcname, autospec=spec
+        ) as get_parent:
             get_parent.return_value = mock.sentinel.parent_device
-            funcname = 'udev_device_ref'
+            funcname = "udev_device_ref"
             spec = lambda d: None
             with mock.patch.object(
-                    a_device._libudev, funcname, autospec=spec) as device_ref:
+                a_device._libudev, funcname, autospec=spec
+            ) as device_ref:
                 device_ref.return_value = mock.sentinel.referenced_device
-                parent = a_device.find_parent('subsystem')
+                parent = a_device.find_parent("subsystem")
                 assert isinstance(parent, Device)
                 assert parent._as_parameter_ is mock.sentinel.referenced_device
-                get_parent.assert_called_once_with(a_device, b'subsystem',
-                                                   None)
+                get_parent.assert_called_once_with(a_device, b"subsystem", None)
                 device_ref.assert_called_once_with(mock.sentinel.parent_device)
 
     @given(strategies.sampled_from(_DEVICES))
     @settings(max_examples=5)
     def test_find_parent_with_devtype_mock(self, a_device):
-        funcname = 'udev_device_get_parent_with_subsystem_devtype'
+        funcname = "udev_device_get_parent_with_subsystem_devtype"
         spec = lambda d, s, t: None
         with mock.patch.object(
-                a_device._libudev, funcname, autospec=spec) as get_parent:
+            a_device._libudev, funcname, autospec=spec
+        ) as get_parent:
             get_parent.return_value = mock.sentinel.parent_device
-            funcname = 'udev_device_ref'
+            funcname = "udev_device_ref"
             spec = lambda d: None
             with mock.patch.object(
-                    a_device._libudev, funcname, autospec=spec) as device_ref:
+                a_device._libudev, funcname, autospec=spec
+            ) as device_ref:
                 device_ref.return_value = mock.sentinel.referenced_device
-                parent = a_device.find_parent('subsystem', 'devtype')
+                parent = a_device.find_parent("subsystem", "devtype")
                 assert isinstance(parent, Device)
                 assert parent._as_parameter_ is mock.sentinel.referenced_device
-                get_parent.assert_called_once_with(a_device, b'subsystem',
-                                                   b'devtype')
+                get_parent.assert_called_once_with(a_device, b"subsystem", b"devtype")
                 device_ref.assert_called_once_with(mock.sentinel.parent_device)
 
     @given(strategies.sampled_from(_DEVICES))
@@ -170,20 +165,21 @@ class TestDevice(object):
     @settings(max_examples=5)
     def test_subsystem(self, a_context, device_datum):
         device = Devices.from_path(a_context, device_datum.device_path)
-        assert device.subsystem == device_datum.properties['SUBSYSTEM']
+        assert device.subsystem == device_datum.properties["SUBSYSTEM"]
         assert is_unicode_string(device.subsystem)
 
     @given(strategies.sampled_from(_DEVICES))
     @settings(max_examples=5)
     def test_device_sys_name(self, a_device):
-        assert a_device.sys_name.replace('/', '!') == \
-           os.path.basename(a_device.device_path)
+        assert a_device.sys_name.replace("/", "!") == os.path.basename(
+            a_device.device_path
+        )
         assert is_unicode_string(a_device.sys_name)
 
     @given(strategies.sampled_from(_DEVICES))
     @settings(max_examples=5)
     def test_sys_number(self, a_device):
-        match = re.search(r'\d+$', a_device.sys_name)
+        match = re.search(r"\d+$", a_device.sys_name)
         # filter out devices with completely nummeric names (first character
         # doesn't count according to the implementation of libudev)
         if match and match.start() > 1:
@@ -196,7 +192,7 @@ class TestDevice(object):
     @settings(max_examples=5)
     def test_type(self, a_context, device_datum):
         device = Devices.from_path(a_context, device_datum.device_path)
-        assert device.device_type == device_datum.properties.get('DEVTYPE')
+        assert device.device_type == device_datum.properties.get("DEVTYPE")
         if device.device_type:
             assert is_unicode_string(device.device_type)
 
@@ -204,7 +200,7 @@ class TestDevice(object):
     @settings(max_examples=5)
     def test_driver(self, a_context, device_datum):
         device = Devices.from_path(a_context, device_datum.device_path)
-        assert device.driver == device_datum.properties.get('DRIVER')
+        assert device.driver == device_datum.properties.get("DRIVER")
         if device.driver:
             assert is_unicode_string(device.driver)
 
@@ -232,10 +228,9 @@ class TestDevice(object):
     @given(strategies.sampled_from(_DEVICES))
     @settings(max_examples=5)
     def test_is_initialized_mock(self, a_device):
-        funcname = 'udev_device_get_is_initialized'
+        funcname = "udev_device_get_is_initialized"
         spec = lambda d: None
-        with mock.patch.object(
-                a_device._libudev, funcname, autospec=spec) as func:
+        with mock.patch.object(a_device._libudev, funcname, autospec=spec) as func:
             func.return_value = False
             assert not a_device.is_initialized
             func.assert_called_once_with(a_device)
@@ -250,10 +245,9 @@ class TestDevice(object):
     @given(strategies.sampled_from(_DEVICES))
     @settings(max_examples=5)
     def test_time_since_initialized_mock(self, a_device):
-        funcname = 'udev_device_get_usec_since_initialized'
+        funcname = "udev_device_get_usec_since_initialized"
         spec = lambda d: None
-        with mock.patch.object(
-                a_device._libudev, funcname, autospec=spec) as func:
+        with mock.patch.object(a_device._libudev, funcname, autospec=spec) as func:
             func.return_value = 100
             assert a_device.time_since_initialized.microseconds == 100
             func.assert_called_once_with(a_device)
@@ -274,12 +268,11 @@ class TestDevice(object):
     @given(strategies.sampled_from(_DEVICES))
     @settings(max_examples=5)
     def test_action_mock(self, a_device):
-        funcname = 'udev_device_get_action'
+        funcname = "udev_device_get_action"
         spec = lambda d: None
-        with mock.patch.object(
-                a_device._libudev, funcname, autospec=spec) as func:
-            func.return_value = b'spam'
-            assert a_device.action == 'spam'
+        with mock.patch.object(a_device._libudev, funcname, autospec=spec) as func:
+            func.return_value = b"spam"
+            assert a_device.action == "spam"
             func.assert_called_once_with(a_device)
             func.reset_mock()
             assert is_unicode_string(a_device.action)
@@ -308,7 +301,7 @@ class TestDevice(object):
 
         https://github.com/lunaryorn/pyudev/issues/32
         """
-        for _ in _CONTEXT.list_devices(subsystem='usb'):
+        for _ in _CONTEXT.list_devices(subsystem="usb"):
             pass
         # make sure that no memory leaks
         assert not gc.garbage
@@ -338,8 +331,9 @@ class TestDevice(object):
         Verify that the keys in the device and in the datum are equal.
         """
         device = Devices.from_path(a_context, device_datum.device_path)
-        assert frozenset(device_datum.properties.keys()) == \
-           frozenset(device.properties.keys())
+        assert frozenset(device_datum.properties.keys()) == frozenset(
+            device.properties.keys()
+        )
 
     @given(_CONTEXT_STRATEGY, strategies.sampled_from(_DEVICE_DATA))
     @settings(max_examples=100)
@@ -348,37 +342,43 @@ class TestDevice(object):
         Verify that the device contains all the keys in the device datum.
         """
         device = Devices.from_path(a_context, device_datum.device_path)
-        assert frozenset(device_datum.properties.keys()) <= \
-           frozenset(device.properties.keys())
+        assert frozenset(device_datum.properties.keys()) <= frozenset(
+            device.properties.keys()
+        )
 
     @given(_CONTEXT_STRATEGY, strategies.sampled_from(_DEVICE_DATA))
     @settings(max_examples=1)
     def test_getitem(self, a_context, device_datum):
         device = Devices.from_path(a_context, device_datum.device_path)
         for prop in device_datum.properties:
-            if prop == 'DEVLINKS':
-                assert sorted(device.properties[prop].split(),) == \
-                   sorted(device_datum.properties[prop].split(),)
-            elif prop == 'TAGS':
-                assert sorted(device.properties[prop].split(':'),) == \
-                   sorted(device_datum.properties[prop].split(':'),)
+            if prop == "DEVLINKS":
+                assert sorted(device.properties[prop].split(),) == sorted(
+                    device_datum.properties[prop].split(),
+                )
+            elif prop == "TAGS":
+                assert sorted(device.properties[prop].split(":"),) == sorted(
+                    device_datum.properties[prop].split(":"),
+                )
             else:
                 # Do not test equality of device properties with udevadm oracle.
                 # https://bugzilla.redhat.com/show_bug.cgi?id=1787089
                 pass
 
-    _device_data = [d for d in _DEVICE_DATA if 'DEVNAME' in d.properties]
+    _device_data = [d for d in _DEVICE_DATA if "DEVNAME" in d.properties]
 
     @pytest.mark.skipif(
-        len(_device_data) == 0, reason='no device with a DEVNAME property')
+        len(_device_data) == 0, reason="no device with a DEVNAME property"
+    )
     @given(_CONTEXT_STRATEGY, strategies.sampled_from(_device_data))
     @settings(max_examples=5)
     def test_getitem_devname(self, a_context, device_datum):
         device = Devices.from_path(a_context, device_datum.device_path)
-        data_devname = os.path.join(a_context.device_path,
-                                    device_datum.properties['DEVNAME'])
-        device_devname = \
-           os.path.join(a_context.device_path, device.properties['DEVNAME'])
+        data_devname = os.path.join(
+            a_context.device_path, device_datum.properties["DEVNAME"]
+        )
+        device_devname = os.path.join(
+            a_context.device_path, device.properties["DEVNAME"]
+        )
         assert device_devname == data_devname
 
     @given(strategies.sampled_from(_DEVICES))
@@ -386,8 +386,8 @@ class TestDevice(object):
     def test_getitem_nonexisting(self, a_device):
         with pytest.raises(KeyError) as excinfo:
             # pylint: disable=pointless-statement
-            a_device.properties['a non-existing property']
-        assert str(excinfo.value) == repr('a non-existing property')
+            a_device.properties["a non-existing property"]
+        assert str(excinfo.value) == repr("a non-existing property")
 
     @given(_CONTEXT_STRATEGY, strategies.sampled_from(_DEVICE_DATA))
     @settings(max_examples=5)
@@ -414,9 +414,9 @@ class TestDevice(object):
         """
         device = Devices.from_path(a_context, device_datum.device_path)
         for prop, value in device_datum.properties.items():
-            if value == '1':
+            if value == "1":
                 assert device.properties.asbool(prop)
-            elif value == '0':
+            elif value == "0":
                 assert not device.properties.asbool(prop)
             else:
                 with pytest.raises(ValueError) as exc_info:
@@ -457,17 +457,19 @@ class TestDevice(object):
         for comp_op in operators:
             with pytest.raises(TypeError) as exc_info:
                 comp_op(a_device, a_device)
-            assert str(exc_info.value) == 'Device not orderable'
+            assert str(exc_info.value) == "Device not orderable"
 
     _devices = [
-       d for d in _DEVICES if \
-          d.device_type == 'disk' and \
-          'ID_WWN_WITH_EXTENSION' in d.properties and \
-          'DM_MULTIPATH_TIMESTAMP' not in d.properties
+        d
+        for d in _DEVICES
+        if d.device_type == "disk"
+        and "ID_WWN_WITH_EXTENSION" in d.properties
+        and "DM_MULTIPATH_TIMESTAMP" not in d.properties
     ]
 
     @pytest.mark.skipif(
-        len(_devices) == 0, reason='unsafe to check ID_WWN_WITH_EXTENSION')
+        len(_devices) == 0, reason="unsafe to check ID_WWN_WITH_EXTENSION"
+    )
     @given(strategies.sampled_from(_devices))
     @settings(max_examples=5)
     def test_id_wwn_with_extension(self, a_device):
@@ -480,10 +482,10 @@ class TestDevice(object):
         Skip any multipathed paths, see:
         https://bugzilla.redhat.com/show_bug.cgi?id=1263441.
         """
-        id_wwn = a_device.properties['ID_WWN_WITH_EXTENSION']
-        assert a_device.subsystem == u'block'
+        id_wwn = a_device.properties["ID_WWN_WITH_EXTENSION"]
+        assert a_device.subsystem == "block"
 
-        id_path = '/dev/disk/by-id'
+        id_path = "/dev/disk/by-id"
         link_name = "wwn-%s" % id_wwn
         match = next((d for d in os.listdir(id_path) if d == link_name), None)
         assert match is not None
