@@ -22,6 +22,3 @@
 
     .. moduleauthor::  Sebastian Wiesner  <lunaryorn@gmail.com>
 """
-
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
