@@ -14,7 +14,6 @@
 # You should have received a copy of the GNU Lesser General Public License
 # along with this library; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
-
 """
     tests.test_discover
     ===================
@@ -24,35 +23,29 @@
     .. moduleauthor:: mulhern <amulhern@redhat.com>
 """
 
-
-from __future__ import absolute_import
-from __future__ import division
-from __future__ import print_function
-from __future__ import unicode_literals
-
+# isort: STDLIB
 import os
 
-import pyudev
-
-from pyudev import DeviceFileHypothesis
-from pyudev import DeviceNameHypothesis
-from pyudev import DeviceNumberHypothesis
-from pyudev import DevicePathHypothesis
-from pyudev import Discovery
-
+# isort: THIRDPARTY
 import pytest
+from hypothesis import assume, given, settings, strategies
 
-from hypothesis import assume
-from hypothesis import given
-from hypothesis import settings
-from hypothesis import strategies
-
+# isort: LOCAL
+import pyudev
+from pyudev import (
+    DeviceFileHypothesis,
+    DeviceNameHypothesis,
+    DeviceNumberHypothesis,
+    DevicePathHypothesis,
+    Discovery,
+)
 
 _CONTEXT = pyudev.Context()
-_DEVICES = _CONTEXT.list_devices()
+_DEVICES = [d for d in _CONTEXT.list_devices()]
 
 NUM_TESTS = 5
 
+
 class TestUtilities(object):
     """
     Some utilities used by the actual tests.
@@ -84,7 +77,7 @@ class TestUtilities(object):
         :rtype: tuple of str
         """
         sys_path = a_device.sys_path
-        (_, _, truncated_path) = sys_path[1:].partition('/')
+        (_, _, truncated_path) = sys_path[1:].partition("/")
         return (sys_path, truncated_path, a_device.device_path)
 
     @staticmethod
@@ -105,6 +98,7 @@ class TestUtilities(object):
             links.append(device_node)
         return links
 
+
 class TestDiscovery(object):
     """
     Test discovery of an object from limited bits of its description.
@@ -115,8 +109,8 @@ class TestDiscovery(object):
     _DISCOVER.setup(_CONTEXT)
 
     @given(
-       strategies.sampled_from(_DEVICES).filter(lambda x: x.device_number),
-       strategies.text(":, -/+=").filter(lambda x: x)
+        strategies.sampled_from(_DEVICES).filter(lambda x: x.device_number),
+        strategies.text(":, -/+=").filter(lambda x: x),
     )
     @settings(max_examples=NUM_TESTS)
     def test_device_number(self, a_device, a_string):
@@ -154,39 +148,17 @@ class TestDiscovery(object):
         assert a_device in res
 
     _devices = [d for d in _DEVICES if list(d.device_links)]
-    @pytest.mark.skipif(
-        len(_devices) == 0,
-        reason="no device with device links"
-    )
-    @given(strategies.sampled_from(_devices))
-    @settings(max_examples=NUM_TESTS, min_satisfying_examples=1)
-    def test_device_file(self, a_device):
-        """
-        Test lookup by device file.
-
-        Skip any devices that are multipath device paths because links
-        may point to other paths in multipath group (rhbz#1263441).
-        """
-        assume(not 'DM_MULTIPATH_TIMESTAMP' in a_device.properties)
-        links = TestUtilities.get_files(a_device)
-        devs = frozenset(
-           d for l in links for d in DeviceFileHypothesis.get_devices(
-              self._CONTEXT,
-              l
-           )
-        )
-        assert devs == set((a_device,))
 
     @given(
-       strategies.sampled_from(_DEVICES),
-       strategies.text(":, -/+=").filter(lambda x: x)
+        strategies.sampled_from(_DEVICES),
+        strategies.text(":, -/+=").filter(lambda x: x),
     )
     @settings(max_examples=NUM_TESTS)
     def test_anything(self, a_device, a_string):
         """
         Grab any of the likely candidates for looking up a device.
         """
-        assume(not 'DM_MULTIPATH_TIMESTAMP' in a_device.properties)
+        assume(not "DM_MULTIPATH_TIMESTAMP" in a_device.properties)
 
         values = list(TestUtilities.get_device_numbers(a_device, a_string))
         values.extend(TestUtilities.get_paths(a_device))
@@ -194,10 +166,7 @@ class TestDiscovery(object):
         values.extend(TestUtilities.get_files(a_device))
 
         results = frozenset(
-           d for v in values for d in self._DISCOVER.get_devices(
-              self._CONTEXT,
-              v
-           )
+            d for v in values for d in self._DISCOVER.get_devices(self._CONTEXT, v)
         )
 
         assert a_device in results
