@@ -15,22 +15,29 @@
 # along with this library; if not, write to the Free Software Foundation,
 # Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA
 
-from __future__ import (print_function, division, unicode_literals,
-                        absolute_import)
+# isort: STDLIB
 import random
-
-from datetime import datetime, timedelta
 from contextlib import contextmanager
+from datetime import datetime, timedelta
 from select import select
 
+# isort: THIRDPARTY
 import pytest
-import mock
-
-from pyudev import Monitor, MonitorObserver, Devices
 
+# isort: FIRSTPARTY
+from tests._constants import _UDEV_TEST
 from tests.utils.udev import DeviceDatabase
 
-from tests._constants import _UDEV_TEST
+# isort: LOCAL
+from pyudev import Devices, Monitor, MonitorObserver
+
+try:
+    # isort: STDLIB
+    from unittest import mock
+except ImportError:
+    # isort: THIRDPARTY
+    import mock
+
 
 # many tests just consist of some monkey patching to test, that the Monitor
 # class actually calls out to udev, correctly passing arguments and handling
@@ -41,20 +48,20 @@ from tests._constants import _UDEV_TEST
 
 @pytest.fixture
 def monitor(request):
-    return Monitor.from_netlink(request.getfixturevalue('context'))
+    return Monitor.from_netlink(request.getfixturevalue("context"))
 
 
 @pytest.fixture
 def fake_monitor_device(request):
-    context = request.getfixturevalue('context')
+    context = request.getfixturevalue("context")
     device = random.choice(list(DeviceDatabase.db()))
     return Devices.from_path(context, device.device_path)
 
 
 @contextmanager
 def patch_filter_by(type):
-    add_match = 'udev_monitor_filter_add_match_{0}'.format(type)
-    filter_update = 'udev_monitor_filter_update'
+    add_match = "udev_monitor_filter_add_match_{0}".format(type)
+    filter_update = "udev_monitor_filter_update"
     with pytest.patch_libudev(add_match) as add_match:
         add_match.return_value = 0
         with pytest.patch_libudev(filter_update) as filter_update:
@@ -65,60 +72,58 @@ def patch_filter_by(type):
 class TestMonitor(object):
     def test_from_netlink_invalid_source(self, context):
         with pytest.raises(ValueError) as exc_info:
-            Monitor.from_netlink(context, source='invalid_source')
-        message = ('Invalid source: {0!r}. Must be one of "udev" '
-                   'or "kernel"'.format('invalid_source'))
+            Monitor.from_netlink(context, source="invalid_source")
+        message = 'Invalid source: {0!r}. Must be one of "udev" ' 'or "kernel"'.format(
+            "invalid_source"
+        )
         assert str(exc_info.value) == message
 
     def test_from_netlink_source_udev(self, context):
         monitor = Monitor.from_netlink(context)
         assert monitor._as_parameter_
         assert not monitor.started
-        monitor = Monitor.from_netlink(context, source='udev')
+        monitor = Monitor.from_netlink(context, source="udev")
         assert monitor._as_parameter_
         assert not monitor.started
 
     def test_from_netlink_source_udev_mock(self, context):
-        funcname = 'udev_monitor_new_from_netlink'
+        funcname = "udev_monitor_new_from_netlink"
         spec = lambda c, s: None
-        with mock.patch.object(
-                context._libudev, funcname, autospec=spec) as func:
+        with mock.patch.object(context._libudev, funcname, autospec=spec) as func:
             func.return_value = mock.sentinel.monitor
             monitor = Monitor.from_netlink(context)
             assert monitor._as_parameter_ is mock.sentinel.monitor
             assert not monitor.started
-            func.assert_called_once_with(context, b'udev')
+            func.assert_called_once_with(context, b"udev")
             func.reset_mock()
-            monitor = Monitor.from_netlink(context, 'udev')
+            monitor = Monitor.from_netlink(context, "udev")
             assert monitor._as_parameter_ is mock.sentinel.monitor
             assert not monitor.started
-            func.assert_called_once_with(context, b'udev')
+            func.assert_called_once_with(context, b"udev")
 
     def test_from_netlink_source_kernel(self, context):
-        monitor = Monitor.from_netlink(context, source='kernel')
+        monitor = Monitor.from_netlink(context, source="kernel")
         assert monitor._as_parameter_
         assert not monitor.started
 
     def test_from_netlink_source_kernel_mock(self, context):
-        funcname = 'udev_monitor_new_from_netlink'
+        funcname = "udev_monitor_new_from_netlink"
         spec = lambda c, s: None
-        with mock.patch.object(
-                context._libudev, funcname, autospec=spec) as func:
+        with mock.patch.object(context._libudev, funcname, autospec=spec) as func:
             func.return_value = mock.sentinel.monitor
-            monitor = Monitor.from_netlink(context, 'kernel')
+            monitor = Monitor.from_netlink(context, "kernel")
             assert monitor._as_parameter_ is mock.sentinel.monitor
             assert not monitor.started
-            func.assert_called_once_with(context, b'kernel')
+            func.assert_called_once_with(context, b"kernel")
 
     def test_fileno(self, monitor):
         # we can't do more than check that no exception is thrown
         monitor.fileno()
 
     def test_fileno_mock(self, monitor):
-        funcname = 'udev_monitor_get_fd'
+        funcname = "udev_monitor_get_fd"
         spec = lambda m: None
-        with mock.patch.object(
-                monitor._libudev, funcname, autospec=spec) as func:
+        with mock.patch.object(monitor._libudev, funcname, autospec=spec) as func:
             func.return_value = mock.sentinel.fileno
             assert monitor.fileno() is mock.sentinel.fileno
             func.assert_called_once_with(monitor)
@@ -128,53 +133,52 @@ class TestMonitor(object):
             monitor.filter_by(None)
 
     def test_filter_by_subsystem_no_dev_type(self, monitor):
-        monitor.filter_by(b'input')
-        monitor.filter_by('input')
+        monitor.filter_by(b"input")
+        monitor.filter_by("input")
 
     def test_filter_by_subsystem_no_dev_type_mock(self, monitor):
-        funcname = 'udev_monitor_filter_add_match_subsystem_devtype'
+        funcname = "udev_monitor_filter_add_match_subsystem_devtype"
         spec = lambda m, s, t: None
         libudev = monitor._libudev
         with mock.patch.object(libudev, funcname, autospec=spec) as match:
-            funcname = 'udev_monitor_filter_update'
+            funcname = "udev_monitor_filter_update"
             spec = lambda m: None
             with mock.patch.object(libudev, funcname, autospec=spec) as update:
-                monitor.filter_by('input')
-                match.assert_called_once_with(monitor, b'input', None)
+                monitor.filter_by("input")
+                match.assert_called_once_with(monitor, b"input", None)
                 update.assert_called_once_with(monitor)
 
     def test_filter_by_subsystem_dev_type(self, monitor):
-        monitor.filter_by('input', b'usb_interface')
-        monitor.filter_by('input', 'usb_interface')
+        monitor.filter_by("input", b"usb_interface")
+        monitor.filter_by("input", "usb_interface")
 
     def test_filter_by_subsystem_dev_type_mock(self, monitor):
-        funcname = 'udev_monitor_filter_add_match_subsystem_devtype'
+        funcname = "udev_monitor_filter_add_match_subsystem_devtype"
         spec = lambda m, s, t: None
         libudev = monitor._libudev
         with mock.patch.object(libudev, funcname, autospec=spec) as match:
-            funcname = 'udev_monitor_filter_update'
+            funcname = "udev_monitor_filter_update"
             spec = lambda m: None
             with mock.patch.object(libudev, funcname, autospec=spec) as update:
-                monitor.filter_by('input', 'usb_interface')
-                match.assert_called_once_with(monitor, b'input',
-                                              b'usb_interface')
+                monitor.filter_by("input", "usb_interface")
+                match.assert_called_once_with(monitor, b"input", b"usb_interface")
                 update.assert_called_once_with(monitor)
 
     @_UDEV_TEST(154, "test_filter_by_tag")
     def test_filter_by_tag(self, monitor):
-        monitor.filter_by_tag('spam')
+        monitor.filter_by_tag("spam")
 
     @_UDEV_TEST(154, "test_filter_by_tag")
     def test_filter_by_tag_mock(self, monitor):
-        funcname = 'udev_monitor_filter_add_match_tag'
+        funcname = "udev_monitor_filter_add_match_tag"
         spec = lambda m, t: None
         libudev = monitor._libudev
         with mock.patch.object(libudev, funcname, autospec=spec) as match:
-            funcname = 'udev_monitor_filter_update'
+            funcname = "udev_monitor_filter_update"
             spec = lambda m: None
             with mock.patch.object(libudev, funcname, autospec=spec) as update:
-                monitor.filter_by_tag('eggs')
-                match.assert_called_once_with(monitor, b'eggs')
+                monitor.filter_by_tag("eggs")
+                match.assert_called_once_with(monitor, b"eggs")
                 update.assert_called_once_with(monitor)
 
     def test_remove_filter(self, monitor):
@@ -187,27 +191,26 @@ class TestMonitor(object):
             monitor.remove_filter()
 
     def test_remove_filter_mock(self, monitor):
-        funcname = 'udev_monitor_filter_remove'
+        funcname = "udev_monitor_filter_remove"
         libudev = monitor._libudev
         spec = lambda m: None
         with mock.patch.object(libudev, funcname, autospec=spec) as remove:
-            funcname = 'udev_monitor_filter_update'
+            funcname = "udev_monitor_filter_update"
             with mock.patch.object(libudev, funcname, autospec=spec) as update:
                 monitor.remove_filter()
                 remove.assert_called_once_with(monitor)
                 update.assert_called_once_with(monitor)
 
     def test_start_netlink_kernel_source(self, context):
-        monitor = Monitor.from_netlink(context, source='kernel')
+        monitor = Monitor.from_netlink(context, source="kernel")
         assert not monitor.started
         monitor.start()
         assert monitor.started
 
     def test_start_mock(self, monitor):
-        funcname = 'udev_monitor_enable_receiving'
+        funcname = "udev_monitor_enable_receiving"
         spec = lambda m: None
-        with mock.patch.object(
-                monitor._libudev, funcname, autospec=spec) as func:
+        with mock.patch.object(monitor._libudev, funcname, autospec=spec) as func:
             assert not monitor.started
             monitor.start()
             assert monitor.started
@@ -218,15 +221,14 @@ class TestMonitor(object):
         """
         Test that enable_receiving() is deprecated and calls out to start().
         """
-        with mock.patch.object(monitor, 'start') as start:
+        with mock.patch.object(monitor, "start") as start:
             pytest.deprecated_call(monitor.enable_receiving)
             assert start.called
 
     def test_set_receive_buffer_size_mock(self, monitor):
-        funcname = 'udev_monitor_set_receive_buffer_size'
+        funcname = "udev_monitor_set_receive_buffer_size"
         spec = lambda m, s: None
-        with mock.patch.object(
-                monitor._libudev, funcname, autospec=spec) as func:
+        with mock.patch.object(monitor._libudev, funcname, autospec=spec) as func:
             monitor.set_receive_buffer_size(1000)
             func.assert_called_once_with(monitor, 1000)
 
@@ -241,12 +243,12 @@ class TestMonitor(object):
         Test that Monitor.receive_device is deprecated and calls out to
         poll(), which in turn is tested by test_poll.
         """
-        with mock.patch.object(monitor, 'poll') as poll:
-            device = mock.Mock(name='device')
-            device.action = 'spam'
+        with mock.patch.object(monitor, "poll") as poll:
+            device = mock.Mock(name="device")
+            device.action = "spam"
             poll.return_value = device
             event = pytest.deprecated_call(monitor.receive_device)
-            assert event[0] == 'spam'
+            assert event[0] == "spam"
             assert event[1] is device
 
 
@@ -263,12 +265,14 @@ class TestMonitorObserver(object):
 
     def make_observer(self, monitor, use_deprecated=False):
         if use_deprecated:
-            if pytest.__version__ == '2.8.4':
+            if pytest.__version__ == "2.8.4":
                 self.observer = MonitorObserver(
-                    monitor, event_handler=self.event_handler)
+                    monitor, event_handler=self.event_handler
+                )
             else:
                 self.observer = pytest.deprecated_call(
-                    MonitorObserver, monitor, event_handler=self.event_handler)
+                    MonitorObserver, monitor, event_handler=self.event_handler
+                )
         else:
             self.observer = MonitorObserver(monitor, callback=self.callback)
         return self.observer
